==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/eo.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informo pri la ĉefprocesoro ne disponeblas",
    "Load average" : "Ŝarĝa mezonombro",
    "Last minute" : "Lasta minuto",
    "Memory info not available" : "Memorinformo ne disponeblas",
    "Total" : "Sumo",
    "Current usage" : "Nuna uzado",
    "Users" : "Uzantoj",
    "Groups" : "Grupoj",
    "Links" : "Ligiloj",
    "Mails" : "Retpoŝtoj",
    "Federated sent" : "Federe senditaj",
    "Federated received" : "Federe ricevitaj",
    "Talk conversations" : "Buŝaj konversacioj",
    "24 hours" : "24 horoj",
    "1 hour" : "1 horo",
    "5 mins" : "5 min",
    "Copy" : "Kopii",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "System" : "Sistemo",
    "Monitoring" : "Observado",
    "Monitoring app with useful server information" : "Observa aplikaĵo kun utilaj informoj pri la servilo",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Montras utilajn servilajn informojn, kiel ŝarĝon de la ĉefprocesoro, ĉefmemoran uzadon, diskan uzadon, nombrojn de uzantoj, k.t.p.",
    "Operating System" : "Operaciumo",
    "CPU" : "Ĉefprocesoro",
    "Memory" : "Ĉefmemoro",
    "Server time" : "Servila horo",
    "Uptime" : "Daŭro de funkciado",
    "Time Servers" : "Temposerviloj",
    "Load" : "Ŝarĝo",
    "Disk" : "Disko",
    "Mount" : "Surmetingo",
    "Filesystem" : "Dosiersistemo",
    "Size" : "Grando",
    "Available" : "Disponeblaj",
    "Used" : "Uzitaj",
    "You will get a notification once one of your disks is nearly full." : "Ni sciigos vin, kiam disko preskaŭ plenos.",
    "Files:" : "Dosieroj:",
    "Storages:" : "Konservejoj:",
    "Free Space:" : "Libera spaco:",
    "Network" : "Reto",
    "Hostname" : "Gastigonomo",
    "DNS" : "DNS",
    "Gateway" : "Kluzo",
    "Status" : "Stato",
    "Speed" : "Rapideco",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktivaj uzantoj",
    "Total users:" : "Sumo de uzantoj:",
    "Shares" : "Kunhavoj",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory Limit:" : "Memorlimo:",
    "Max Execution Time:" : "Maksimuma tempo de rulado:",
    "Upload max size:" : "Maksimuma alŝutgrando:",
    "Database" : "Datumbazo",
    "Type:" : "Tipo:",
    "Size:" : "Grando:",
    "External monitoring tool" : "Ekstera observa ilo",
    "You can connect an external monitoring tool by using this end point:" : "Vi povas konekti esteran observan ilo per tiu adreso:",
    "Did you know?" : "Ĉu vi sciis?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Postaldoni „?format=json“ fine de la adreso liveras al vi la rezulton en JSON-formo!",
    "Last 24 hours" : "Lastaj 24 horoj",
    "Last 1 hour" : "Lasta horo",
    "Last 5 mins" : "Lastaj 5 min",
    "CPU load" : "Ĉefprocesora ŝarĝo",
    "Memory usage" : "Memora uzado",
    "Storage" : "Konservejo",
    "Users:" : "Uzantoj:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Aplikaĵoj instalitaj:",
    "Apps updates available:" : "Aplikaĵoj ĝisdatigotaj:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/eo.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informo pri la ĉefprocesoro ne disponeblas",
    "Load average" : "Ŝarĝa mezonombro",
    "Last minute" : "Lasta minuto",
    "Memory info not available" : "Memorinformo ne disponeblas",
    "Total" : "Sumo",
    "Current usage" : "Nuna uzado",
    "Users" : "Uzantoj",
    "Groups" : "Grupoj",
    "Links" : "Ligiloj",
    "Mails" : "Retpoŝtoj",
    "Federated sent" : "Federe senditaj",
    "Federated received" : "Federe ricevitaj",
    "Talk conversations" : "Buŝaj konversacioj",
    "24 hours" : "24 horoj",
    "1 hour" : "1 horo",
    "5 mins" : "5 min",
    "Copy" : "Kopii",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "System" : "Sistemo",
    "Monitoring" : "Observado",
    "Monitoring app with useful server information" : "Observa aplikaĵo kun utilaj informoj pri la servilo",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Montras utilajn servilajn informojn, kiel ŝarĝon de la ĉefprocesoro, ĉefmemoran uzadon, diskan uzadon, nombrojn de uzantoj, k.t.p.",
    "Operating System" : "Operaciumo",
    "CPU" : "Ĉefprocesoro",
    "Memory" : "Ĉefmemoro",
    "Server time" : "Servila horo",
    "Uptime" : "Daŭro de funkciado",
    "Time Servers" : "Temposerviloj",
    "Load" : "Ŝarĝo",
    "Disk" : "Disko",
    "Mount" : "Surmetingo",
    "Filesystem" : "Dosiersistemo",
    "Size" : "Grando",
    "Available" : "Disponeblaj",
    "Used" : "Uzitaj",
    "You will get a notification once one of your disks is nearly full." : "Ni sciigos vin, kiam disko preskaŭ plenos.",
    "Files:" : "Dosieroj:",
    "Storages:" : "Konservejoj:",
    "Free Space:" : "Libera spaco:",
    "Network" : "Reto",
    "Hostname" : "Gastigonomo",
    "DNS" : "DNS",
    "Gateway" : "Kluzo",
    "Status" : "Stato",
    "Speed" : "Rapideco",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktivaj uzantoj",
    "Total users:" : "Sumo de uzantoj:",
    "Shares" : "Kunhavoj",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory Limit:" : "Memorlimo:",
    "Max Execution Time:" : "Maksimuma tempo de rulado:",
    "Upload max size:" : "Maksimuma alŝutgrando:",
    "Database" : "Datumbazo",
    "Type:" : "Tipo:",
    "Size:" : "Grando:",
    "External monitoring tool" : "Ekstera observa ilo",
    "You can connect an external monitoring tool by using this end point:" : "Vi povas konekti eksteran observan ilon per tiu adreso:",
    "Did you know?" : "Ĉu vi sciis?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Postaldoni „?format=json“ fine de la adreso liveras al vi la rezulton en JSON-formo!"
},
"nplurals=2; plural=(n != 1);");
